@@ -892,7 +892,7 @@ sub keybinder {
         }
     }
     elsif ($key eq KEY_F(1)) {
-        my $text = `man as.cui 2>/dev/null` || "Cannot launch man or man page for as.cui not found";
+        my $text = `man as-cui 2>/dev/null` || "Cannot launch man or man page for as-cui not found";
         my $w = $this->parent->add("help", 'TextViewer',
             -x          => $matrixwidget->{"XOffset"},
             -y          => $matrixwidget->{"YOffset"},
